summaryrefslogtreecommitdiff
path: root/round-robin.sh
diff options
context:
space:
mode:
authorThiago Jung Bauermann <thiago.bauermann@linaro.org>2024-03-04 20:23:46 -0300
committerThiago Bauermann <thiago.bauermann@linaro.org>2024-03-12 16:17:09 +0000
commit1134e0483ffac8d3c9c73ac67c2b0963661ffe81 (patch)
tree7c2a86dfb95c68e246f6707c1b38da387bfd27d0 /round-robin.sh
parente9c38a1f72486e78efd00332f3769d2f42730122 (diff)
round-robin.sh: Double flaky entries timespans in build_abe()
There have been some false positives in both GCC and GDB regression reports because flaky entries expired before the CI could re-detect them. Address this problem by increasing expiration date for flaky entries from 6 to 12 weeks, and by increasing the window where we try to detect flaky entries before they expire from 4 weeks to 8 weeks. Also, fix typo in one of the comments (s/what/that/). Change-Id: Id3458a42591da4291054b4bdbeb6f64e63cd2838
Diffstat (limited to 'round-robin.sh')
-rw-r--r--round-robin.sh12
1 files changed, 6 insertions, 6 deletions
diff --git a/round-robin.sh b/round-robin.sh
index 7c855a0a..e9ffb764 100644
--- a/round-robin.sh
+++ b/round-robin.sh
@@ -489,14 +489,14 @@ build_abe ()
if [ "${rr[update_baseline]}" != "ignore" ]; then
# If we have a chance to commit $new_flaky into base-artifacts.git
- # then pretend it is 4 weeks into the future and ignore flaky entries
- # what will be expired by then. This, effectively, gives us 4 weeks
+ # then pretend it is 8 weeks into the future and ignore flaky entries
+ # that will be expired by then. This, effectively, gives us 8 weeks
# to re-detect/confirm flaky tests without no_regression_p()
# noticing anything.
# We will then set expiration date to "now+6 weeks" (see below)
# for entries in $new_flaky/"sumfiles/flaky.xfail".
local week_from_now
- week_from_now=$(date -d "now+4 weeks" +%Y%m%d)
+ week_from_now=$(date -d "now+8 weeks" +%Y%m%d)
rerun_failed_tests+=("--failures-expiration-date" "$week_from_now")
fi
@@ -824,13 +824,13 @@ build_abe ()
sumfiles="$run_step_top_artifacts/00-sumfiles"
fi
# Mark new flaky entries to expire in 6 weeks.
# The upside of expiration is that we will have an up-to-date list
# of flaky tests, which we can address.
# The downside is that we will spend a bit more CPU cycles
# to re-detect flaky tests.
local expire
- expire=$(date -d "now+6 weeks" +%Y%m%d)
+ expire=$(date -d "now+12 weeks" +%Y%m%d)
# A lot of thought went into the following nugget:
expire="expire=$expire"
sed -i -e "s#^flaky | #flaky,$expire | #" "$flaky_tests"
@@ -489,14 +489,14 @@ build_abe ()
# to re-detect/confirm flaky tests without no_regression_p()
# noticing anything.
- # We will then set expiration date to "now+6 weeks" (see below)
+ # We will then set expiration date to "now+12 weeks" (see below)
# for entries in $new_flaky/"sumfiles/flaky.xfail".
local week_from_now
@@ -824,13 +824,13 @@ build_abe ()
sumfiles="$run_step_top_artifacts/00-sumfiles"
fi
- # Mark new flaky entries to expire in 6 weeks.
+ # Mark new flaky entries to expire in 12 weeks.
# The upside of expiration is that we will have an up-to-date list
# of flaky tests, which we can address.